# Generated by Django 5.2.6 on 2026-04-06 07:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("confetti", "0002_alter_settingdefinition_choices_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="settingcategory",
            options={
                "verbose_name": "Категория настройки",
                "verbose_name_plural": "Категории настроек",
            },
        ),
        migrations.AlterModelOptions(
            name="settingdefinition",
            options={
                "ordering": ["key"],
                "verbose_name": "Настройка",
                "verbose_name_plural": "Настройки",
            },
        ),
        migrations.AlterModelOptions(
            name="settingvalue",
            options={
                "verbose_name": "Значение настройки",
                "verbose_name_plural": "Значения настроек",
            },
        ),
        migrations.CreateModel(
            name="SettingsSnapshot",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True, verbose_name="Время создания"
                    ),
                ),
                (
                    "comment",
                    models.CharField(
                        blank=True,
                        help_text="Комментарий к снимку настроек",
                        max_length=255,
                        verbose_name="Комментарий",
                    ),
                ),
                (
                    "payload",
                    models.JSONField(
                        default=list,
                        help_text="Полный снимок глобальных настроек",
                        verbose_name="Снимок данных",
                    ),
                ),
            ],
            options={
                "verbose_name": "Снимок настроек",
                "verbose_name_plural": "Снимки настроек",
                "ordering": ["-created_at", "-id"],
            },
        ),
        migrations.AlterField(
            model_name="settingdefinition",
            name="choices",
            field=models.JSONField(
                blank=True,
                default=[],
                help_text="Список объектов, у объекта ключ value обязателен, этот ключ храниться в default в виде списка",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="settingdefinition",
            name="default",
            field=models.JSONField(blank=True, default=[], null=True),
        ),
    ]
