# Generated by Django 4.2.3 on 2026-04-06 10:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('confetti', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='settingdefinition',
            name='choices',
            field=models.JSONField(blank=True, default=[], help_text='Список объектов, у объекта ключ value обязателен, этот ключ храниться в default в виде списка', null=True),
        ),
        migrations.AlterField(
            model_name='settingdefinition',
            name='default',
            field=models.JSONField(blank=True, default=[], null=True),
        ),
    ]
